@@ -1,5 +1,7 @@
+# frozen_string_literal: true
+
 module ActsAsTaggableOn
-  class Tagging < ::ActiveRecord::Base #:nodoc:
+  class Tagging < ::ActiveRecord::Base # :nodoc:
     self.table_name = ActsAsTaggableOn.taggings_table
 
     DEFAULT_CONTEXT = 'tags'
@@ -19,7 +21,7 @@ module ActsAsTaggableOn
     validates_presence_of :context
     validates_presence_of :tag_id
 
-    validates_uniqueness_of :tag_id, scope: [:taggable_type, :taggable_id, :context, :tagger_id, :tagger_type]
+    validates_uniqueness_of :tag_id, scope: %i[taggable_type taggable_id context tagger_id tagger_type]
 
     after_destroy :remove_unused_tags
 
@@ -29,8 +31,8 @@ module ActsAsTaggableOn
       if ActsAsTaggableOn.remove_unused_tags
         if ActsAsTaggableOn.tags_counter
           tag.destroy if tag.reload.taggings_count.zero?
-        else
-          tag.destroy if tag.reload.taggings.none?
+        elsif tag.reload.taggings.none?
+          tag.destroy
         end
       end
     end
