@@ -1,3 +1,5 @@
+# frozen_string_literal: true
+
 # This module is deprecated and will be removed in the incoming versions
 
 module ActsAsTaggableOn
@@ -9,7 +11,7 @@ module ActsAsTaggableOn
       end
 
       def using_postgresql?
-        connection && connection.adapter_name == 'PostgreSQL'
+        connection && %w[PostgreSQL PostGIS].include?(connection.adapter_name)
       end
 
       def using_mysql?
@@ -30,7 +32,7 @@ module ActsAsTaggableOn
 
       # escape _ and % characters in strings, since these are wildcards in SQL.
       def escape_like(str)
-        str.gsub(/[!%_]/) { |x| '!' + x }
+        str.gsub(/[!%_]/) { |x| "!#{x}" }
       end
     end
   end
